close all
clear all
clc 

%Read 2D Damage and Loss Data
Depth_2D = xlsread('Building_Archetypes_Data_2D','Depth');
DS0_2D = xlsread('Building_Archetypes_Data_2D','DS0_2D');
DS1_2D = xlsread('Building_Archetypes_Data_2D','DS1_2D');
DS2_2D = xlsread('Building_Archetypes_Data_2D','DS2_2D');
DS3_2D = xlsread('Building_Archetypes_Data_2D','DS3_2D');
DS4_2D = xlsread('Building_Archetypes_Data_2D','DS4_2D');
DS_LN_Par = xlsread('Building_RC_Table','Fragility_Parameters');
Loss_M1_2D = xlsread('Building_Archetypes_Data_2D','Loss_M1_2D');
Loss_M2_2D = xlsread('Building_Archetypes_Data_2D','Loss_M2_2D');
Loss_HAZUS_2D = xlsread('HAZUS_Data','HAZUS_Losses');
Loss_M1_2D_std = xlsread('Building_Archetypes_Data_2D','Loss_M2_2D');
n_Arch = 15;
n_DS = 5;

%% Build 2-D Fragility Matrix
F_2D_Fragility = zeros(length(Depth_2D),n_Arch,n_DS);
F_2D_Fragility(:,:,1) = DS0_2D;
F_2D_Fragility(:,:,2) = DS1_2D;
F_2D_Fragility(:,:,3) = DS2_2D;
F_2D_Fragility(:,:,4) = DS3_2D;
F_2D_Fragility(:,:,5) = DS4_2D;

%Building 2-D Loss Matrix
F_2D_Loss_M1 = Loss_M1_2D;
F_2D_Loss_M2 = Loss_M2_2D;
F_2D_Loss_M1_std = Loss_M1_2D_std;

%% Plot the 2-D Fragility and loss curves
for i = 1:5
    figure(i)
    plot(Depth_2D,F_2D_Fragility(:,:,i),'LineWidth', 1.5); hold on
    xlabel('Flood Depth (m)','FontName','Times New Roman','FontSize',14)
    ylabel('Probability of Exceedance','FontName','Times New Roman','FontSize',14)
    set(gca,'FontName',['Times New Roman'])
    set(gcf,'color','w')
end

figure(1)
set(gcf,'color','w')
xlim([0 3])
ylim([0 1])
legend({'F1','F3'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

figure(2)
set(gcf,'color','w')
xlim([0 3])
ylim([0 1])
legend({'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10','F11','F12','F13','F14','F15'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

figure(3)
set(gcf,'color','w')
xlim([0 3])
ylim([0 1])
legend({'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10','F11','F12','F13','F14','F15'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

figure(4)
set(gcf,'color','w')
xlim([0 10])
ylim([0 1])
legend({'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10','F11','F12','F13','F14','F15'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

figure(5)
set(gcf,'color','w')
xlim([1 10])
ylim([0 1])
legend({'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10','F11','F12','F13','F14','F15'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

%% Plot the 2-D Fragility and loss curves
for i = 1:15
    for k = 2:5
        figure(i+100)
        plot(Depth_2D,F_2D_Fragility(:,i,k),'LineWidth', 1.5); hold on
        xlabel('Flood Depth (m)','FontName','Times New Roman','FontSize',14)
        ylabel('Probability of Exceedance','FontName','Times New Roman','FontSize',14)
        set(gca,'FontName',['Times New Roman'])
        set(gcf,'color','w')
    end
    legend({'DS1','DS2','DS3','DS4'},...
    'FontName','Times New Roman','FontSize',12,'Location','southeast')
end

figure(101)
plot(Depth_2D,F_2D_Fragility(:,1,1),'LineWidth', 1.5); hold on
set(gcf,'color','w')
xlim([0 10])
ylim([0 1])
legend({'DS0','DS1','DS2','DS3','DS4'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

figure(103)
plot(Depth_2D,F_2D_Fragility(:,3,1),'LineWidth', 1.5); hold on
set(gcf,'color','w')
xlim([0 10])
ylim([0 1])
legend({'DS0','DS1','DS2','DS3','DS4'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

%% Plotting the fragilities using the lognormal parameters

%Constructing the parameters matrix 
meu = zeros(n_Arch,n_DS);
sigma = zeros(n_Arch,n_DS);
meu_DS0 = DS_LN_Par(:, 1); meu(:,1) = meu_DS0;
meu_DS1 = DS_LN_Par(:, 3); meu(:,2) = meu_DS1;
meu_DS2 = DS_LN_Par(:, 5); meu(:,3) = meu_DS2;
meu_DS3 = DS_LN_Par(:, 7); meu(:,4) = meu_DS3;
meu_DS4 = DS_LN_Par(:, 9); meu(:,5) = meu_DS4;

sigma_DS0 = DS_LN_Par(:, 2); sigma(:,1) = sigma_DS0;
sigma_DS1 = DS_LN_Par(:, 4); sigma(:,2) = sigma_DS1;
sigma_DS2 = DS_LN_Par(:, 6); sigma(:,3) = sigma_DS2;
sigma_DS3 = DS_LN_Par(:, 8); sigma(:,4) = sigma_DS3;
sigma_DS4 = DS_LN_Par(:, 10); sigma(:,5) = sigma_DS4;


for i=1:15
    for k=2:5
        for m=1:length(Depth_2D)
        p(m,i,k) = logncdf(Depth_2D(m),meu(i,k),sigma(i,k));
        end
    end
end

p(:,1,1) = logncdf(Depth_2D,meu(1,1),sigma(1,1));
p(:,3,1) = logncdf(Depth_2D,meu(3,1),sigma(3,1));

% Plot the 2-D Fragility and loss curves
for i = 1:15
    for k = 2:5
        figure(i+200)
        plot(Depth_2D,p(:,i,k),'LineWidth', 1.5); hold on
        xlabel('Flood Depth (m)','FontName','Times New Roman','FontSize',14)
        ylabel('Probability of Exceedance','FontName','Times New Roman','FontSize',14)
        set(gca,'FontName',['Times New Roman'])
        set(gcf,'color','w')
    end
    legend({'DS1','DS2','DS3','DS4'},...
    'FontName','Times New Roman','FontSize',12,'Location','southeast')
end

figure(201)
plot(Depth_2D,p(:,1,1),'LineWidth', 1.5); hold on
set(gcf,'color','w')
xlim([0 10])
ylim([0 1])
legend({'DS0','DS1','DS2','DS3','DS4'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')

figure(203)
plot(Depth_2D,p(:,3,1),'LineWidth', 1.5); hold on
set(gcf,'color','w')
xlim([0 10])
ylim([0 1])
legend({'DS0','DS1','DS2','DS3','DS4'},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')
%% 
figure(9)
plot(Depth_2D,Loss_M2_2D,'LineWidth', 1.5); hold on
xlabel('Flood Depth (m)','FontName','Times New Roman','FontSize',14)
ylabel('Total Building Loss (%)','FontName','Times New Roman','FontSize',14)
set(gca,'FontName',['Times New Roman'])
set(gcf,'color','w')
legend({'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10','F11','F12','F13','F14','F15',},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')
xlim([0 10])
ylim([0 100])

figure(10)
plot(Depth_2D,Loss_M1_2D,'LineWidth', 1.5); hold on
xlabel('Flood Depth (m)','FontName','Times New Roman','FontSize',14)
ylabel('Total Building Loss (%)','FontName','Times New Roman','FontSize',14)
set(gca,'FontName',['Times New Roman'])
set(gcf,'color','w')
legend({'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10','F11','F12','F13','F14','F15',},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')
xlim([0 10])
ylim([0 100])

figure(8)
plot(Loss_HAZUS_2D(:,1),Loss_HAZUS_2D(:,2:16),'LineWidth', 1.5); hold on
xlabel('Flood Depth (m)','FontName','Times New Roman','FontSize',14)
ylabel('Total Building Loss (%)','FontName','Times New Roman','FontSize',14)
set(gca,'FontName',['Times New Roman'])
set(gcf,'color','w')
legend({'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10','F11','F12','F13','F14','F15',},...
'FontName','Times New Roman','FontSize',12,'Location','southeast')
xlim([0 10])
ylim([0 100])

%% Read 3D Damage and Loss Data
Depth_3D = xlsread('Depth-Duration_3D','Depth');
Duration_3D = xlsread('Depth-Duration_3D','Duration');

F1_DS0_3D = xlsread('F1_3D','F1_DS0_3D');
F1_DS1_3D = xlsread('F1_3D','F1_DS1_3D');
F1_DS2_3D = xlsread('F1_3D','F1_DS2_3D');
F1_DS3_3D = xlsread('F1_3D','F1_DS3_3D');
F1_DS4_3D = xlsread('F1_3D','F1_DS4_3D');
F1_Loss_3D = xlsread('F1_3D','F1_Loss_3D');

F2_DS1_3D = xlsread('F2_3D','F2_DS1_3D');
F2_DS2_3D = xlsread('F2_3D','F2_DS2_3D');
F2_DS3_3D = xlsread('F2_3D','F2_DS3_3D');
F2_DS4_3D = xlsread('F2_3D','F2_DS4_3D');
F2_Loss_3D = xlsread('F2_3D','F2_Loss_3D');

F3_DS0_3D = xlsread('F3_3D','F3_DS0_3D');
F3_DS1_3D = xlsread('F3_3D','F3_DS1_3D');
F3_DS2_3D = xlsread('F3_3D','F3_DS2_3D');
F3_DS3_3D = xlsread('F3_3D','F3_DS3_3D');
F3_DS4_3D = xlsread('F3_3D','F3_DS4_3D');
F3_Loss_3D = xlsread('F3_3D','F3_Loss_3D');

F4_DS1_3D = xlsread('F4_3D','F4_DS1_3D');
F4_DS2_3D = xlsread('F4_3D','F4_DS2_3D');
F4_DS3_3D = xlsread('F4_3D','F4_DS3_3D');
F4_DS4_3D = xlsread('F4_3D','F4_DS4_3D');
F4_Loss_3D = xlsread('F4_3D','F4_Loss_3D');

F5_DS1_3D = xlsread('F5_3D','F5_DS1_3D');
F5_DS2_3D = xlsread('F5_3D','F5_DS2_3D');
F5_DS3_3D = xlsread('F5_3D','F5_DS3_3D');
F5_DS4_3D = xlsread('F5_3D','F5_DS4_3D');
F5_Loss_3D = xlsread('F5_3D','F5_Loss_3D');

F6_DS1_3D = xlsread('F6_3D','F6_DS1_3D');
F6_DS2_3D = xlsread('F6_3D','F6_DS2_3D');
F6_DS3_3D = xlsread('F6_3D','F6_DS3_3D');
F6_DS4_3D = xlsread('F6_3D','F6_DS4_3D');
F6_Loss_3D = xlsread('F6_3D','F6_Loss_3D');

F7_DS1_3D = xlsread('F7_3D','F7_DS1_3D');
F7_DS2_3D = xlsread('F7_3D','F7_DS2_3D');
F7_DS3_3D = xlsread('F7_3D','F7_DS3_3D');
F7_DS4_3D = xlsread('F7_3D','F7_DS4_3D');
F7_Loss_3D = xlsread('F7_3D','F7_Loss_3D');

F8_DS1_3D = xlsread('F8_3D','F8_DS1_3D');
F8_DS2_3D = xlsread('F8_3D','F8_DS2_3D');
F8_DS3_3D = xlsread('F8_3D','F8_DS3_3D');
F8_DS4_3D = xlsread('F8_3D','F8_DS4_3D');
F8_Loss_3D = xlsread('F8_3D','F8_Loss_3D');

F9_DS1_3D = xlsread('F9_3D','F9_DS1_3D');
F9_DS2_3D = xlsread('F9_3D','F9_DS2_3D');
F9_DS3_3D = xlsread('F9_3D','F9_DS3_3D');
F9_DS4_3D = xlsread('F9_3D','F9_DS4_3D');
F9_Loss_3D = xlsread('F9_3D','F9_Loss_3D');

F10_DS1_3D = xlsread('F10_3D','F10_DS1_3D');
F10_DS2_3D = xlsread('F10_3D','F10_DS2_3D');
F10_DS3_3D = xlsread('F10_3D','F10_DS3_3D');
F10_DS4_3D = xlsread('F10_3D','F10_DS4_3D');
F10_Loss_3D = xlsread('F10_3D','F10_Loss_3D');

F11_DS1_3D = xlsread('F11_3D','F11_DS1_3D');
F11_DS2_3D = xlsread('F11_3D','F11_DS2_3D');
F11_DS3_3D = xlsread('F11_3D','F11_DS3_3D');
F11_DS4_3D = xlsread('F11_3D','F11_DS4_3D');
F11_Loss_3D = xlsread('F11_3D','F11_Loss_3D');

F12_DS1_3D = xlsread('F12_3D','F12_DS1_3D');
F12_DS2_3D = xlsread('F12_3D','F12_DS2_3D');
F12_DS3_3D = xlsread('F12_3D','F12_DS3_3D');
F12_DS4_3D = xlsread('F12_3D','F12_DS4_3D');
F12_Loss_3D = xlsread('F12_3D','F12_Loss_3D');

F13_DS1_3D = xlsread('F13_3D','F13_DS1_3D');
F13_DS2_3D = xlsread('F13_3D','F13_DS2_3D');
F13_DS3_3D = xlsread('F13_3D','F13_DS3_3D');
F13_DS4_3D = xlsread('F13_3D','F13_DS4_3D');
F13_Loss_3D = xlsread('F13_3D','F13_Loss_3D');

F14_DS1_3D = xlsread('F14_3D','F14_DS1_3D');
F14_DS2_3D = xlsread('F14_3D','F14_DS2_3D');
F14_DS3_3D = xlsread('F14_3D','F14_DS3_3D');
F14_DS4_3D = xlsread('F14_3D','F14_DS4_3D');
F14_Loss_3D = xlsread('F14_3D','F14_Loss_3D');

F15_DS1_3D = xlsread('F15_3D','F15_DS1_3D');
F15_DS2_3D = xlsread('F15_3D','F15_DS2_3D');
F15_DS3_3D = xlsread('F15_3D','F15_DS3_3D');
F15_DS4_3D = xlsread('F15_3D','F15_DS4_3D');
F15_Loss_3D = xlsread('F15_3D','F15_Loss_3D');

%% Organize the 3-D Fragility Matrix
F_3D_Fragility = zeros(length(Depth_3D),length(Duration_3D),n_Arch,n_DS);
F_3D_Fragility(:,:,1,1) = F1_DS0_3D;
F_3D_Fragility(:,:,1,2) = F1_DS1_3D;
F_3D_Fragility(:,:,1,3) = F1_DS2_3D;
F_3D_Fragility(:,:,1,4) = F1_DS3_3D;
F_3D_Fragility(:,:,1,5) = F1_DS4_3D;

F_3D_Fragility(:,:,2,2) = F2_DS1_3D;
F_3D_Fragility(:,:,2,3) = F2_DS2_3D;
F_3D_Fragility(:,:,2,4) = F2_DS3_3D;
F_3D_Fragility(:,:,2,5) = F2_DS4_3D;

F_3D_Fragility(:,:,3,1) = F3_DS0_3D;
F_3D_Fragility(:,:,3,2) = F3_DS1_3D;
F_3D_Fragility(:,:,3,3) = F3_DS2_3D;
F_3D_Fragility(:,:,3,4) = F3_DS3_3D;
F_3D_Fragility(:,:,3,5) = F3_DS4_3D;

F_3D_Fragility(:,:,4,2) = F4_DS1_3D;
F_3D_Fragility(:,:,4,3) = F4_DS2_3D;
F_3D_Fragility(:,:,4,4) = F4_DS3_3D;
F_3D_Fragility(:,:,4,5) = F4_DS4_3D;

F_3D_Fragility(:,:,5,2) = F5_DS1_3D;
F_3D_Fragility(:,:,5,3) = F5_DS2_3D;
F_3D_Fragility(:,:,5,4) = F5_DS3_3D;
F_3D_Fragility(:,:,5,5) = F5_DS4_3D;

F_3D_Fragility(:,:,6,2) = F6_DS1_3D;
F_3D_Fragility(:,:,6,3) = F6_DS2_3D;
F_3D_Fragility(:,:,6,4) = F6_DS3_3D;
F_3D_Fragility(:,:,6,5) = F6_DS4_3D;

F_3D_Fragility(:,:,7,2) = F7_DS1_3D;
F_3D_Fragility(:,:,7,3) = F7_DS2_3D;
F_3D_Fragility(:,:,7,4) = F7_DS3_3D;
F_3D_Fragility(:,:,7,5) = F7_DS4_3D;

F_3D_Fragility(:,:,8,2) = F8_DS1_3D;
F_3D_Fragility(:,:,8,3) = F8_DS2_3D;
F_3D_Fragility(:,:,8,4) = F8_DS3_3D;
F_3D_Fragility(:,:,8,5) = F8_DS4_3D;

F_3D_Fragility(:,:,9,2) = F9_DS1_3D;
F_3D_Fragility(:,:,9,3) = F9_DS2_3D;
F_3D_Fragility(:,:,9,4) = F9_DS3_3D;
F_3D_Fragility(:,:,9,5) = F9_DS4_3D;

F_3D_Fragility(:,:,10,2) = F10_DS1_3D;
F_3D_Fragility(:,:,10,3) = F10_DS2_3D;
F_3D_Fragility(:,:,10,4) = F10_DS3_3D;
F_3D_Fragility(:,:,10,5) = F10_DS4_3D;

F_3D_Fragility(:,:,11,2) = F11_DS1_3D;
F_3D_Fragility(:,:,11,3) = F11_DS2_3D;
F_3D_Fragility(:,:,11,4) = F11_DS3_3D;
F_3D_Fragility(:,:,11,5) = F11_DS4_3D;

F_3D_Fragility(:,:,12,2) = F12_DS1_3D;
F_3D_Fragility(:,:,12,3) = F12_DS2_3D;
F_3D_Fragility(:,:,12,4) = F12_DS3_3D;
F_3D_Fragility(:,:,12,5) = F12_DS4_3D;

F_3D_Fragility(:,:,13,2) = F13_DS1_3D;
F_3D_Fragility(:,:,13,3) = F13_DS2_3D;
F_3D_Fragility(:,:,13,4) = F13_DS3_3D;
F_3D_Fragility(:,:,13,5) = F13_DS4_3D;

F_3D_Fragility(:,:,14,2) = F14_DS1_3D;
F_3D_Fragility(:,:,14,3) = F14_DS2_3D;
F_3D_Fragility(:,:,14,4) = F14_DS3_3D;
F_3D_Fragility(:,:,14,5) = F14_DS4_3D;

F_3D_Fragility(:,:,15,2) = F15_DS1_3D;
F_3D_Fragility(:,:,15,3) = F15_DS2_3D;
F_3D_Fragility(:,:,15,4) = F15_DS3_3D;
F_3D_Fragility(:,:,15,5) = F15_DS4_3D;

%% Build 3-D Loss Matrix
F_3D_Loss = zeros(length(Depth_3D),length(Duration_3D),n_Arch);
F_3D_Loss(:,:,1) = F1_Loss_3D;
F_3D_Loss(:,:,2) = F2_Loss_3D;
F_3D_Loss(:,:,3) = F3_Loss_3D;
F_3D_Loss(:,:,4) = F4_Loss_3D;
F_3D_Loss(:,:,5) = F5_Loss_3D;
F_3D_Loss(:,:,6) = F6_Loss_3D;
F_3D_Loss(:,:,7) = F7_Loss_3D;
F_3D_Loss(:,:,8) = F8_Loss_3D;
F_3D_Loss(:,:,9) = F9_Loss_3D;
F_3D_Loss(:,:,10) = F10_Loss_3D;
F_3D_Loss(:,:,11) = F11_Loss_3D;
F_3D_Loss(:,:,12) = F12_Loss_3D;
F_3D_Loss(:,:,13) = F13_Loss_3D;
F_3D_Loss(:,:,14) = F14_Loss_3D;
F_3D_Loss(:,:,15) = F15_Loss_3D;


%% Plot 3D Fragility functions
for i = 1:15
    for k = 2:5
        figure(i+300)
        surf(F_3D_Fragility(:,:,i,k))
        set(gcf,'color','w')
        xlim([0 100])
        ylim([0 100])
        zlim([0 1])
        set(gca,'XTick',[1 20 40 60 80 100])
        set(gca,'YTick',[1 20 40 60 80 100])
        set(gca,'XTicklabel',[0 60 120 180 240 300])
        set(gca,'YTicklabel',[0 2 4 6 8 10]);hold on
    end 
end 

figure(201)
surf(F_3D_Fragility(:,:,1,1))

figure(203)
surf(F_3D_Fragility(:,:,3,1))
%% Plot 3D Loss functions
for i = 1:15
    figure(i+400)
    surf(F_3D_Loss(:,:,i))
    set(gcf,'color','w')
    xlim([0 100])
    ylim([0 100])
    zlim([0 101])
    set(gca,'XTick',[1 20 40 60 80 100])
    set(gca,'YTick',[1 20 40 60 80 100])
    set(gca,'XTicklabel',[0 60 120 180 240 300])
    set(gca,'YTicklabel',[0 2 4 6 8 10])
end 

